Documentation
¶
Index ¶
- Constants
- Variables
- func AddTemplateFunc(name string, tmplFunc interface{})
- func AddTemplateFuncs(tmplFuncs template.FuncMap)
- func ArbitraryArgs(cmd *Command, args []string) error
- func CheckErr(msg interface{})
- func CompDebug(msg string, printToStdErr bool)
- func CompDebugln(msg string, printToStdErr bool)
- func CompError(msg string)
- func CompErrorln(msg string)
- func Eq(a interface{}, b interface{}) bool
- func Gt(a interface{}, b interface{}) bool
- func MarkFlagCustom(flags *pflag.FlagSet, name string, f string) error
- func MarkFlagDirname(flags *pflag.FlagSet, name string) error
- func MarkFlagFilename(flags *pflag.FlagSet, name string, extensions ...string) error
- func MarkFlagRequired(flags *pflag.FlagSet, name string) error
- func NoArgs(cmd *Command, args []string) error
- func OnInitialize(y ...func())
- func OnlyValidArgs(cmd *Command, args []string) error
- func WriteStringAndCheck(b io.StringWriter, s string)
- type Cmd
- type Command
- func (c *Command) AddCommand(cmds ...*Command)
- func (c *Command) ArgsLenAtDash() int
- func (c *Command) CalledAs() string
- func (c *Command) CommandPath() string
- func (c *Command) CommandPathPadding() int
- func (c *Command) Commands() []*Command
- func (c *Command) Context() context.Context
- func (c *Command) DebugFlags()
- func (c *Command) ErrOrStderr() io.Writer
- func (c *Command) Execute() error
- func (c *Command) ExecuteC() (cmd *Command, err error)
- func (c *Command) ExecuteContext(ctx context.Context) error
- func (c *Command) ExecuteContextC(ctx context.Context) (*Command, error)
- func (c *Command) Find(args []string) (*Command, []string, error)
- func (c *Command) Flag(name string) (flag *flag.Flag)
- func (c *Command) FlagErrorFunc() (f func(*Command, error) error)
- func (c *Command) Flags() *flag.FlagSet
- func (c *Command) GenBashCompletion(w io.Writer) error
- func (c *Command) GenBashCompletionFile(filename string) error
- func (c *Command) GenBashCompletionFileV2(filename string, includeDesc bool) error
- func (c *Command) GenBashCompletionV2(w io.Writer, includeDesc bool) error
- func (c *Command) GenFishCompletion(w io.Writer, includeDesc bool) error
- func (c *Command) GenFishCompletionFile(filename string, includeDesc bool) error
- func (c *Command) GenPowerShellCompletion(w io.Writer) error
- func (c *Command) GenPowerShellCompletionFile(filename string) error
- func (c *Command) GenPowerShellCompletionFileWithDesc(filename string) error
- func (c *Command) GenPowerShellCompletionWithDesc(w io.Writer) error
- func (c *Command) GenZshCompletion(w io.Writer) error
- func (c *Command) GenZshCompletionFile(filename string) error
- func (c *Command) GenZshCompletionFileNoDesc(filename string) error
- func (c *Command) GenZshCompletionNoDesc(w io.Writer) error
- func (c *Command) GlobalNormalizationFunc() func(f *flag.FlagSet, name string) flag.NormalizedName
- func (c *Command) HasAlias(s string) bool
- func (c *Command) HasAvailableFlags() bool
- func (c *Command) HasAvailableInheritedFlags() bool
- func (c *Command) HasAvailableLocalFlags() bool
- func (c *Command) HasAvailablePersistentFlags() bool
- func (c *Command) HasAvailableSubCommands() bool
- func (c *Command) HasExample() bool
- func (c *Command) HasFlags() bool
- func (c *Command) HasHelpSubCommands() bool
- func (c *Command) HasInheritedFlags() bool
- func (c *Command) HasLocalFlags() bool
- func (c *Command) HasParent() bool
- func (c *Command) HasPersistentFlags() bool
- func (c *Command) HasSubCommands() bool
- func (c *Command) Help() error
- func (c *Command) HelpFunc() func(*Command, []string)
- func (c *Command) HelpTemplate() string
- func (c *Command) InOrStdin() io.Reader
- func (c *Command) InheritedFlags() *flag.FlagSet
- func (c *Command) InitDefaultHelpCmd()
- func (c *Command) InitDefaultHelpFlag()
- func (c *Command) InitDefaultVersionFlag()
- func (c *Command) IsAdditionalHelpTopicCommand() bool
- func (c *Command) IsAvailableCommand() bool
- func (c *Command) LocalFlags() *flag.FlagSet
- func (c *Command) LocalNonPersistentFlags() *flag.FlagSet
- func (c *Command) MarkFlagCustom(name string, f string) error
- func (c *Command) MarkFlagDirname(name string) error
- func (c *Command) MarkFlagFilename(name string, extensions ...string) error
- func (c *Command) MarkFlagRequired(name string) error
- func (c *Command) MarkPersistentFlagDirname(name string) error
- func (c *Command) MarkPersistentFlagFilename(name string, extensions ...string) error
- func (c *Command) MarkPersistentFlagRequired(name string) error
- func (c *Command) MarkZshCompPositionalArgumentFile(argPosition int, patterns ...string) error
- func (c *Command) MarkZshCompPositionalArgumentWords(argPosition int, words ...string) error
- func (c *Command) Name() string
- func (c *Command) NameAndAliases() string
- func (c *Command) NamePadding() int
- func (c *Command) NonInheritedFlags() *flag.FlagSet
- func (c *Command) OutOrStderr() io.Writer
- func (c *Command) OutOrStdout() io.Writer
- func (c *Command) Parent() *Command
- func (c *Command) ParseFlags(args []string) error
- func (c *Command) PersistentFlags() *flag.FlagSet
- func (c *Command) Print(i ...interface{})
- func (c *Command) PrintErr(i ...interface{})
- func (c *Command) PrintErrf(format string, i ...interface{})
- func (c *Command) PrintErrln(i ...interface{})
- func (c *Command) Printf(format string, i ...interface{})
- func (c *Command) Println(i ...interface{})
- func (c *Command) RegisterFlagCompletionFunc(flagName string, ...) error
- func (c *Command) RemoveCommand(cmds ...*Command)
- func (c *Command) ResetCommands()
- func (c *Command) ResetFlags()
- func (c *Command) Root() *Command
- func (c *Command) Runnable() bool
- func (c *Command) SetArgs(a []string)
- func (c *Command) SetErr(newErr io.Writer)
- func (c *Command) SetFlagErrorFunc(f func(*Command, error) error)
- func (c *Command) SetGlobalNormalizationFunc(n func(f *flag.FlagSet, name string) flag.NormalizedName)
- func (c *Command) SetHelpCommand(cmd *Command)
- func (c *Command) SetHelpFunc(f func(*Command, []string))
- func (c *Command) SetHelpTemplate(s string)
- func (c *Command) SetIn(newIn io.Reader)
- func (c *Command) SetOut(newOut io.Writer)
- func (c *Command) SetOutput(output io.Writer)
- func (c *Command) SetUsageFunc(f func(*Command) error)
- func (c *Command) SetUsageTemplate(s string)
- func (c *Command) SetVersionTemplate(s string)
- func (c *Command) SuggestionsFor(typedName string) []string
- func (c *Command) Traverse(args []string) (*Command, []string, error)
- func (c *Command) Usage() error
- func (c *Command) UsageFunc() (f func(*Command) error)
- func (c *Command) UsagePadding() int
- func (c *Command) UsageString() string
- func (c *Command) UsageTemplate() string
- func (c *Command) UseLine() string
- func (c *Command) ValidateArgs(args []string) error
- func (c *Command) VersionTemplate() string
- func (c *Command) VisitParents(fn func(*Command))
- type CompletionOptions
- type Config
- type FParseErrWhitelist
- type PositionalArgs
- type ShellCompDirective
Constants ¶
const ( BashCompFilenameExt = "cobra_annotation_bash_completion_filename_extensions" BashCompCustom = "cobra_annotation_bash_completion_custom" BashCompOneRequiredFlag = "cobra_annotation_bash_completion_one_required_flag" BashCompSubdirsInDir = "cobra_annotation_bash_completion_subdirs_in_dir" )
Annotations for Bash completion.
const ( // ShellCompRequestCmd is the name of the hidden command that is used to request // completion results from the program. It is used by the shell completion scripts. ShellCompRequestCmd = "__complete" // ShellCompNoDescRequestCmd is the name of the hidden command that is used to request // completion results without their description. It is used by the shell completion scripts. ShellCompNoDescRequestCmd = "__completeNoDesc" )
Variables ¶
var ( Log *zdpgo_log.Log Shell = zdpgo_shell.New() Env = zdpgo_env.New() )
var EnableCommandSorting = true
EnableCommandSorting controls sorting of the slice of commands, which is turned on by default. To disable sorting, set it to false.
var EnablePrefixMatching = false
EnablePrefixMatching allows to set automatic prefix matching. Automatic prefix matching can be a dangerous thing to automatically enable in CLI tools. Set this to true to enable it.
var MousetrapDisplayDuration = 5 * time.Second
MousetrapDisplayDuration controls how long the MousetrapHelpText message is displayed on Windows if the CLI is started from explorer.exe. Set to 0 to wait for the return key to be pressed. To disable the mousetrap, just set MousetrapHelpText to blank string (""). Works only on Microsoft Windows.
var MousetrapHelpText = `This is a command line tool.
You need to open cmd.exe and run it from there.
`
MousetrapHelpText enables an information splash screen on Windows if the CLI is started from explorer.exe. To disable the mousetrap, just set this variable to blank string (""). Works only on Microsoft Windows.
Functions ¶
func AddTemplateFunc ¶ added in v0.1.2
func AddTemplateFunc(name string, tmplFunc interface{})
AddTemplateFunc adds a template function that's available to Usage and Help template generation.
func AddTemplateFuncs ¶ added in v0.1.2
AddTemplateFuncs adds multiple template functions that are available to Usage and Help template generation.
func ArbitraryArgs ¶ added in v0.1.2
ArbitraryArgs never returns an error.
func CheckErr ¶ added in v0.1.2
func CheckErr(msg interface{})
CheckErr prints the msg with the prefix 'Error:' and exits with error code 1. If the msg is nil, it does nothing.
func CompDebug ¶ added in v0.1.2
CompDebug prints the specified string to the same file as where the completion script prints its logs. Note that completion printouts should never be on stdout as they would be wrongly interpreted as actual completion choices by the completion script.
func CompDebugln ¶ added in v0.1.2
CompDebugln prints the specified string with a newline at the end to the same file as where the completion script prints its logs. Such logs are only printed when the user has set the environment variable BASH_COMP_DEBUG_FILE to the path of some file to be used.
func CompError ¶ added in v0.1.2
func CompError(msg string)
CompError prints the specified completion message to stderr.
func CompErrorln ¶ added in v0.1.2
func CompErrorln(msg string)
CompErrorln prints the specified completion message to stderr with a newline at the end.
func Eq ¶ added in v0.1.2
func Eq(a interface{}, b interface{}) bool
Eq takes two types and checks whether they are equal. Supported types are int and string. Unsupported types will panic.
func Gt ¶ added in v0.1.2
func Gt(a interface{}, b interface{}) bool
Gt takes two types and checks whether the first type is greater than the second. In case of types Arrays, Chans, Maps and Slices, Gt will compare their lengths. Ints are compared directly while strings are first parsed as ints and then compared.
func MarkFlagCustom ¶ added in v0.1.2
MarkFlagCustom adds the BashCompCustom annotation to the named flag, if it exists. The bash completion script will call the bash function f for the flag.
This will only work for bash completion. It is recommended to instead use c.RegisterFlagCompletionFunc(...) which allows to register a Go function which will work across all shells.
func MarkFlagDirname ¶ added in v0.1.2
MarkFlagDirname instructs the various shell completion implementations to limit completions for the named flag to directory names.
func MarkFlagFilename ¶ added in v0.1.2
MarkFlagFilename instructs the various shell completion implementations to limit completions for the named flag to the specified file extensions.
func MarkFlagRequired ¶ added in v0.1.2
MarkFlagRequired instructs the various shell completion implementations to prioritize the named flag when performing completion, and causes your command to report an error if invoked without the flag.
func OnInitialize ¶ added in v0.1.2
func OnInitialize(y ...func())
OnInitialize sets the passed functions to be run when each command's Execute method is called.
func OnlyValidArgs ¶ added in v0.1.2
OnlyValidArgs returns an error if any args are not in the list of ValidArgs.
func WriteStringAndCheck ¶ added in v0.1.2
func WriteStringAndCheck(b io.StringWriter, s string)
WriteStringAndCheck writes a string into a buffer, and checks if the error is not nil.
Types ¶
type Command ¶ added in v0.1.2
type Command struct {
// Use 是一行使用信息。
// 建议的语法如下:
// [ ] 标识可选参数。不包含在括号内的参数是必需的。
// ... 指示可以为上一个参数指定多个值。
// | 表示相互排斥的信息。可以使用分隔符左侧的参数,也可以使用分隔符右侧的参数。不能在命令的一次使用中同时使用这两个参数。
// { } 当需要一个参数时,分隔一组相互排斥的参数。如果参数是可选的,则将其括在括号([])中。
// Example: add [-F file | -D dir]... [-f format] profile
Use string
// Aliases 是一组别名,可以用来代替Use中的第一个单词。
Aliases []string
// SuggestFor 是一个命令名数组,该命令将被建议使用类似于别名,但仅建议使用。
SuggestFor []string
// Short 是“帮助”输出中显示的简短描述。
Short string
// Long 是“help<this command>”输出中显示的长消息。
Long string
// Example 是如何使用该命令的示例。
Example string
// ValidArgs 是shell完成中接受的所有有效非标志参数的列表
ValidArgs []string
// ValidArgsFunction 是一个可选函数,为shell完成提供有效的非标志参数。
// 这是使用ValidArgs的动态版本。
// 一个命令只能使用ValidArgs和ValidArgsFunction中的一个。
ValidArgsFunction func(cmd *Command, args []string, toComplete string) ([]string, ShellCompDirective)
// 预期参数
Args PositionalArgs
// ArgAliases 是ValidArgs的别名列表。
// 在shell completion中不建议用户使用这些选项,但如果手动输入,则可以接受这些选项。
ArgAliases []string
// BashCompletionFunction 是传统bash自动完成生成器使用的自定义bash函数。
// 为了便于携带其他Shell,建议改用ValidArgsFunction
BashCompletionFunction string
// Deprecated 定义,如果此命令已弃用,并且在使用时应打印此字符串。
Deprecated string
// Annotations 是应用程序可以用来识别或分组命令的键/值对。
Annotations map[string]string
// Version 定义此命令的版本。
// 如果该值非空且命令未定义“版本”标志,则将向命令添加“版本”布尔标志
// 如果指定,将打印“版本”变量的内容。
// 如果命令没有定义,也会添加一个简写的“v”标志。
Version string
// The *Run functions are executed in the following order:
// * PersistentPreRun()
// * PreRun()
// * Run()
// * PostRun()
// * PersistentPostRun()
// All functions get the same args, the arguments after the command name.
//
// PersistentPreRun: 此命令的子命令将继承并执行。
PersistentPreRun func(cmd *Command, args []string)
// PersistentPreRunE: PersistentPreRun 但是返回错误
PersistentPreRunE func(cmd *Command, args []string) error
// PreRun: 子命令不会继承
PreRun func(cmd *Command, args []string)
// PreRunE: PreRun 但是不返回错误
PreRunE func(cmd *Command, args []string) error
// Run: 通常是实际的功函数。大多数命令只能实现这一点。
Run func(cmd *Command, args []string)
// RunE: Run 但是返回一个错误
RunE func(cmd *Command, args []string) error
// PostRun: 在Run之后执行
PostRun func(cmd *Command, args []string)
// PostRunE: PostRun 但是返回一个错误
PostRunE func(cmd *Command, args []string) error
// PersistentPostRun:子命令会继承,并在 PostRun 之后执行
PersistentPostRun func(cmd *Command, args []string)
// PersistentPostRunE: PersistentPostRun 但是返回错误
PersistentPostRunE func(cmd *Command, args []string) error
//FParseErrWhitelist flag parse errors to be ignored
FParseErrWhitelist FParseErrWhitelist
// CompletionOptions is a set of options to control the handling of shell completion
CompletionOptions CompletionOptions
// TraverseChildren parses flags on all parents before executing child command.
TraverseChildren bool
// Hidden defines, if this command is hidden and should NOT show up in the list of available commands.
Hidden bool
// SilenceErrors is an option to quiet errors down stream.
SilenceErrors bool
// SilenceUsage is an option to silence usage when an error occurs.
SilenceUsage bool
// DisableFlagParsing disables the flag parsing.
// If this is true all flags will be passed to the command as arguments.
DisableFlagParsing bool
// DisableAutoGenTag defines, if gen tag ("Auto generated by spf13/cobra...")
// will be printed by generating docs for this command.
DisableAutoGenTag bool
// DisableFlagsInUseLine will disable the addition of [flags] to the usage
// line of a command when printing help or generating docs
DisableFlagsInUseLine bool
// DisableSuggestions disables the suggestions based on Levenshtein distance
// that go along with 'unknown command' messages.
DisableSuggestions bool
// SuggestionsMinimumDistance defines minimum levenshtein distance to display suggestions.
// Must be > 0.
SuggestionsMinimumDistance int
// contains filtered or unexported fields
}
Command 这就是你的应用程序的命令。 您需要将用法和描述定义为命令定义的一部分,以确保可用性。
func (*Command) AddCommand ¶ added in v0.1.2
AddCommand 添加1个或者多个子命令
func (*Command) ArgsLenAtDash ¶ added in v0.1.2
ArgsLenAtDash will return the length of c.Flags().Args at the moment when a -- was found during args parsing.
func (*Command) CalledAs ¶ added in v0.1.2
CalledAs returns the command name or alias that was used to invoke this command or an empty string if the command has not been called.
func (*Command) CommandPath ¶ added in v0.1.2
CommandPath returns the full path to this command.
func (*Command) CommandPathPadding ¶ added in v0.1.2
CommandPathPadding return padding for the command path.
func (*Command) Context ¶ added in v0.1.2
Context returns underlying command context. If command wasn't executed with ExecuteContext Context returns Background context.
func (*Command) DebugFlags ¶ added in v0.1.2
func (c *Command) DebugFlags()
DebugFlags used to determine which flags have been assigned to which commands and which persist.
func (*Command) ErrOrStderr ¶ added in v0.1.2
ErrOrStderr returns output to stderr
func (*Command) Execute ¶ added in v0.1.2
Execute uses the args (os.Args[1:] by default) and run through the command tree finding appropriate matches for commands and then corresponding flags.
func (*Command) ExecuteContext ¶ added in v0.1.2
ExecuteContext is the same as Execute(), but sets the ctx on the command. Retrieve ctx by calling cmd.Context() inside your *Run lifecycle or ValidArgs functions.
func (*Command) ExecuteContextC ¶ added in v0.1.2
ExecuteContextC is the same as ExecuteC(), but sets the ctx on the command. Retrieve ctx by calling cmd.Context() inside your *Run lifecycle or ValidArgs functions.
func (*Command) Find ¶ added in v0.1.2
Find the target command given the args and command tree Meant to be run on the highest node. Only searches down.
func (*Command) FlagErrorFunc ¶ added in v0.1.2
FlagErrorFunc returns either the function set by SetFlagErrorFunc for this command or a parent, or it returns a function which returns the original error.
func (*Command) Flags ¶ added in v0.1.2
Flags returns the complete FlagSet that applies to this command (local and persistent declared here and by all parents).
func (*Command) GenBashCompletion ¶ added in v0.1.2
GenBashCompletion generates bash completion file and writes to the passed writer.
func (*Command) GenBashCompletionFile ¶ added in v0.1.2
GenBashCompletionFile generates bash completion file.
func (*Command) GenBashCompletionFileV2 ¶ added in v0.1.2
GenBashCompletionFileV2 generates Bash completion version 2.
func (*Command) GenBashCompletionV2 ¶ added in v0.1.2
GenBashCompletionV2 generates Bash completion file version 2 and writes it to the passed writer.
func (*Command) GenFishCompletion ¶ added in v0.1.2
GenFishCompletion generates fish completion file and writes to the passed writer.
func (*Command) GenFishCompletionFile ¶ added in v0.1.2
GenFishCompletionFile generates fish completion file.
func (*Command) GenPowerShellCompletion ¶ added in v0.1.2
GenPowerShellCompletion generates powershell completion file without descriptions and writes it to the passed writer.
func (*Command) GenPowerShellCompletionFile ¶ added in v0.1.2
GenPowerShellCompletionFile generates powershell completion file without descriptions.
func (*Command) GenPowerShellCompletionFileWithDesc ¶ added in v0.1.2
GenPowerShellCompletionFileWithDesc generates powershell completion file with descriptions.
func (*Command) GenPowerShellCompletionWithDesc ¶ added in v0.1.2
GenPowerShellCompletionWithDesc generates powershell completion file with descriptions and writes it to the passed writer.
func (*Command) GenZshCompletion ¶ added in v0.1.2
GenZshCompletion generates zsh completion file including descriptions and writes it to the passed writer.
func (*Command) GenZshCompletionFile ¶ added in v0.1.2
GenZshCompletionFile generates zsh completion file including descriptions.
func (*Command) GenZshCompletionFileNoDesc ¶ added in v0.1.2
GenZshCompletionFileNoDesc generates zsh completion file without descriptions.
func (*Command) GenZshCompletionNoDesc ¶ added in v0.1.2
GenZshCompletionNoDesc generates zsh completion file without descriptions and writes it to the passed writer.
func (*Command) GlobalNormalizationFunc ¶ added in v0.1.2
GlobalNormalizationFunc returns the global normalization function or nil if it doesn't exist.
func (*Command) HasAlias ¶ added in v0.1.2
HasAlias determines if a given string is an alias of the command.
func (*Command) HasAvailableFlags ¶ added in v0.1.2
HasAvailableFlags checks if the command contains any flags (local plus persistent from the entire structure) which are not hidden or deprecated.
func (*Command) HasAvailableInheritedFlags ¶ added in v0.1.2
HasAvailableInheritedFlags checks if the command has flags inherited from its parent command which are not hidden or deprecated.
func (*Command) HasAvailableLocalFlags ¶ added in v0.1.2
HasAvailableLocalFlags checks if the command has flags specifically declared locally which are not hidden or deprecated.
func (*Command) HasAvailablePersistentFlags ¶ added in v0.1.2
HasAvailablePersistentFlags checks if the command contains persistent flags which are not hidden or deprecated.
func (*Command) HasAvailableSubCommands ¶ added in v0.1.2
HasAvailableSubCommands determines if a command has available sub commands that need to be shown in the usage/help default template under 'available commands'.
func (*Command) HasExample ¶ added in v0.1.2
HasExample determines if the command has example.
func (*Command) HasFlags ¶ added in v0.1.2
HasFlags checks if the command contains any flags (local plus persistent from the entire structure).
func (*Command) HasHelpSubCommands ¶ added in v0.1.2
HasHelpSubCommands determines if a command has any available 'help' sub commands that need to be shown in the usage/help default template under 'additional help topics'.
func (*Command) HasInheritedFlags ¶ added in v0.1.2
HasInheritedFlags checks if the command has flags inherited from its parent command.
func (*Command) HasLocalFlags ¶ added in v0.1.2
HasLocalFlags checks if the command has flags specifically declared locally.
func (*Command) HasPersistentFlags ¶ added in v0.1.2
HasPersistentFlags checks if the command contains persistent flags.
func (*Command) HasSubCommands ¶ added in v0.1.2
HasSubCommands determines if the command has children commands.
func (*Command) Help ¶ added in v0.1.2
Help puts out the help for the command. Used when a user calls help [command]. Can be defined by user by overriding HelpFunc.
func (*Command) HelpFunc ¶ added in v0.1.2
HelpFunc returns either the function set by SetHelpFunc for this command or a parent, or it returns a function with default help behavior.
func (*Command) HelpTemplate ¶ added in v0.1.2
HelpTemplate return help template for the command.
func (*Command) InheritedFlags ¶ added in v0.1.2
InheritedFlags returns all flags which were inherited from parent commands.
func (*Command) InitDefaultHelpCmd ¶ added in v0.1.2
func (c *Command) InitDefaultHelpCmd()
InitDefaultHelpCmd adds default help command to c. It is called automatically by executing the c or by calling help and usage. If c already has help command or c has no subcommands, it will do nothing.
func (*Command) InitDefaultHelpFlag ¶ added in v0.1.2
func (c *Command) InitDefaultHelpFlag()
InitDefaultHelpFlag adds default help flag to c. It is called automatically by executing the c or by calling help and usage. If c already has help flag, it will do nothing.
func (*Command) InitDefaultVersionFlag ¶ added in v0.1.2
func (c *Command) InitDefaultVersionFlag()
InitDefaultVersionFlag adds default version flag to c. It is called automatically by executing the c. If c already has a version flag, it will do nothing. If c.Version is empty, it will do nothing.
func (*Command) IsAdditionalHelpTopicCommand ¶ added in v0.1.2
IsAdditionalHelpTopicCommand determines if a command is an additional help topic command; additional help topic command is determined by the fact that it is NOT runnable/hidden/deprecated, and has no sub commands that are runnable/hidden/deprecated. Concrete example: https://github.com/zhangdapeng520/zdpgo_cmd/cobra/issues/393#issuecomment-282741924.
func (*Command) IsAvailableCommand ¶ added in v0.1.2
IsAvailableCommand determines if a command is available as a non-help command (this includes all non deprecated/hidden commands).
func (*Command) LocalFlags ¶ added in v0.1.2
LocalFlags returns the local FlagSet specifically set in the current command.
func (*Command) LocalNonPersistentFlags ¶ added in v0.1.2
LocalNonPersistentFlags are flags specific to this command which will NOT persist to subcommands.
func (*Command) MarkFlagCustom ¶ added in v0.1.2
MarkFlagCustom adds the BashCompCustom annotation to the named flag, if it exists. The bash completion script will call the bash function f for the flag.
This will only work for bash completion. It is recommended to instead use c.RegisterFlagCompletionFunc(...) which allows to register a Go function which will work across all shells.
func (*Command) MarkFlagDirname ¶ added in v0.1.2
MarkFlagDirname instructs the various shell completion implementations to limit completions for the named flag to directory names.
func (*Command) MarkFlagFilename ¶ added in v0.1.2
MarkFlagFilename instructs the various shell completion implementations to limit completions for the named flag to the specified file extensions.
func (*Command) MarkFlagRequired ¶ added in v0.1.2
MarkFlagRequired instructs the various shell completion implementations to prioritize the named flag when performing completion, and causes your command to report an error if invoked without the flag.
func (*Command) MarkPersistentFlagDirname ¶ added in v0.1.2
MarkPersistentFlagDirname instructs the various shell completion implementations to limit completions for the named persistent flag to directory names.
func (*Command) MarkPersistentFlagFilename ¶ added in v0.1.2
MarkPersistentFlagFilename instructs the various shell completion implementations to limit completions for the named persistent flag to the specified file extensions.
func (*Command) MarkPersistentFlagRequired ¶ added in v0.1.2
MarkPersistentFlagRequired instructs the various shell completion implementations to prioritize the named persistent flag when performing completion, and causes your command to report an error if invoked without the flag.
func (*Command) MarkZshCompPositionalArgumentFile ¶ added in v0.1.2
MarkZshCompPositionalArgumentFile only worked for zsh and its behavior was not consistent with Bash completion. It has therefore been disabled. Instead, when no other completion is specified, file completion is done by default for every argument. One can disable file completion on a per-argument basis by using ValidArgsFunction and ShellCompDirectiveNoFileComp. To achieve file extension filtering, one can use ValidArgsFunction and ShellCompDirectiveFilterFileExt.
Deprecated
func (*Command) MarkZshCompPositionalArgumentWords ¶ added in v0.1.2
MarkZshCompPositionalArgumentWords only worked for zsh. It has therefore been disabled. To achieve the same behavior across all shells, one can use ValidArgs (for the first argument only) or ValidArgsFunction for any argument (can include the first one also).
Deprecated
func (*Command) Name ¶ added in v0.1.2
Name returns the command's name: the first word in the use line.
func (*Command) NameAndAliases ¶ added in v0.1.2
NameAndAliases returns a list of the command name and all aliases
func (*Command) NamePadding ¶ added in v0.1.2
NamePadding returns padding for the name.
func (*Command) NonInheritedFlags ¶ added in v0.1.2
NonInheritedFlags returns all flags which were not inherited from parent commands.
func (*Command) OutOrStderr ¶ added in v0.1.2
OutOrStderr returns output to stderr
func (*Command) OutOrStdout ¶ added in v0.1.2
OutOrStdout returns output to stdout.
func (*Command) ParseFlags ¶ added in v0.1.2
ParseFlags parses persistent flag tree and local flags.
func (*Command) PersistentFlags ¶ added in v0.1.2
PersistentFlags returns the persistent FlagSet specifically set in the current command.
func (*Command) Print ¶ added in v0.1.2
func (c *Command) Print(i ...interface{})
Print is a convenience method to Print to the defined output, fallback to Stderr if not set.
func (*Command) PrintErr ¶ added in v0.1.2
func (c *Command) PrintErr(i ...interface{})
PrintErr is a convenience method to Print to the defined Err output, fallback to Stderr if not set.
func (*Command) PrintErrf ¶ added in v0.1.2
PrintErrf is a convenience method to Printf to the defined Err output, fallback to Stderr if not set.
func (*Command) PrintErrln ¶ added in v0.1.2
func (c *Command) PrintErrln(i ...interface{})
PrintErrln is a convenience method to Println to the defined Err output, fallback to Stderr if not set.
func (*Command) Printf ¶ added in v0.1.2
Printf is a convenience method to Printf to the defined output, fallback to Stderr if not set.
func (*Command) Println ¶ added in v0.1.2
func (c *Command) Println(i ...interface{})
Println is a convenience method to Println to the defined output, fallback to Stderr if not set.
func (*Command) RegisterFlagCompletionFunc ¶ added in v0.1.2
func (c *Command) RegisterFlagCompletionFunc(flagName string, f func(cmd *Command, args []string, toComplete string) ([]string, ShellCompDirective)) error
RegisterFlagCompletionFunc should be called to register a function to provide completion for a flag.
func (*Command) RemoveCommand ¶ added in v0.1.2
RemoveCommand removes one or more commands from a parent command.
func (*Command) ResetCommands ¶ added in v0.1.2
func (c *Command) ResetCommands()
ResetCommands delete parent, subcommand and help command from c.
func (*Command) ResetFlags ¶ added in v0.1.2
func (c *Command) ResetFlags()
ResetFlags deletes all flags from command.
func (*Command) SetArgs ¶ added in v0.1.2
SetArgs sets arguments for the command. It is set to os.Args[1:] by default, if desired, can be overridden particularly useful when testing.
func (*Command) SetErr ¶ added in v0.1.2
SetErr sets the destination for error messages. If newErr is nil, os.Stderr is used.
func (*Command) SetFlagErrorFunc ¶ added in v0.1.2
SetFlagErrorFunc sets a function to generate an error when flag parsing fails.
func (*Command) SetGlobalNormalizationFunc ¶ added in v0.1.2
func (c *Command) SetGlobalNormalizationFunc(n func(f *flag.FlagSet, name string) flag.NormalizedName)
SetGlobalNormalizationFunc sets a normalization function to all flag sets and also to child commands. The user should not have a cyclic dependency on commands.
func (*Command) SetHelpCommand ¶ added in v0.1.2
SetHelpCommand sets help command.
func (*Command) SetHelpFunc ¶ added in v0.1.2
SetHelpFunc sets help function. Can be defined by Application.
func (*Command) SetHelpTemplate ¶ added in v0.1.2
SetHelpTemplate sets help template to be used. Application can use it to set custom template.
func (*Command) SetIn ¶ added in v0.1.2
SetIn sets the source for input data If newIn is nil, os.Stdin is used.
func (*Command) SetOut ¶ added in v0.1.2
SetOut sets the destination for usage messages. If newOut is nil, os.Stdout is used.
func (*Command) SetOutput ¶ added in v0.1.2
SetOutput sets the destination for usage and error messages. If output is nil, os.Stderr is used. Deprecated: Use SetOut and/or SetErr instead
func (*Command) SetUsageFunc ¶ added in v0.1.2
SetUsageFunc sets usage function. Usage can be defined by application.
func (*Command) SetUsageTemplate ¶ added in v0.1.2
SetUsageTemplate sets usage template. Can be defined by Application.
func (*Command) SetVersionTemplate ¶ added in v0.1.2
SetVersionTemplate sets version template to be used. Application can use it to set custom template.
func (*Command) SuggestionsFor ¶ added in v0.1.2
SuggestionsFor provides suggestions for the typedName.
func (*Command) Traverse ¶ added in v0.1.2
Traverse the command tree to find the command, and parse args for each parent.
func (*Command) Usage ¶ added in v0.1.2
Usage puts out the usage for the command. Used when a user provides invalid input. Can be defined by user by overriding UsageFunc.
func (*Command) UsageFunc ¶ added in v0.1.2
UsageFunc returns either the function set by SetUsageFunc for this command or a parent, or it returns a default usage function.
func (*Command) UsagePadding ¶ added in v0.1.2
UsagePadding return padding for the usage.
func (*Command) UsageString ¶ added in v0.1.2
UsageString returns usage string.
func (*Command) UsageTemplate ¶ added in v0.1.2
UsageTemplate returns usage template for the command.
func (*Command) UseLine ¶ added in v0.1.2
UseLine puts out the full usage for a given command (including parents).
func (*Command) ValidateArgs ¶ added in v0.1.2
func (*Command) VersionTemplate ¶ added in v0.1.2
VersionTemplate return version template for the command.
func (*Command) VisitParents ¶ added in v0.1.2
VisitParents visits all parents of the command and invokes fn on each parent.
type CompletionOptions ¶ added in v0.1.2
type CompletionOptions struct {
// DisableDefaultCmd prevents Cobra from creating a default 'completion' command
DisableDefaultCmd bool
// DisableNoDescFlag prevents Cobra from creating the '--no-descriptions' flag
// for shells that support completion descriptions
DisableNoDescFlag bool
// DisableDescriptions turns off all completion descriptions for shells
// that support them
DisableDescriptions bool
// HiddenDefaultCmd makes the default 'completion' command hidden
HiddenDefaultCmd bool
}
CompletionOptions are the options to control shell completion
type FParseErrWhitelist ¶ added in v0.1.2
type FParseErrWhitelist flag.ParseErrorsWhitelist
FParseErrWhitelist configures Flag parse errors to be ignored
type PositionalArgs ¶ added in v0.1.2
func ExactArgs ¶ added in v0.1.2
func ExactArgs(n int) PositionalArgs
ExactArgs returns an error if there are not exactly n args.
func ExactValidArgs ¶ added in v0.1.2
func ExactValidArgs(n int) PositionalArgs
ExactValidArgs returns an error if there are not exactly N positional args OR there are any positional args that are not in the `ValidArgs` field of `Command`
func MatchAll ¶ added in v0.1.2
func MatchAll(pargs ...PositionalArgs) PositionalArgs
MatchAll allows combining several PositionalArgs to work in concert.
func MaximumNArgs ¶ added in v0.1.2
func MaximumNArgs(n int) PositionalArgs
MaximumNArgs returns an error if there are more than N args.
func MinimumNArgs ¶ added in v0.1.2
func MinimumNArgs(n int) PositionalArgs
MinimumNArgs returns an error if there is not at least N args.
func RangeArgs ¶ added in v0.1.2
func RangeArgs(min int, max int) PositionalArgs
RangeArgs returns an error if the number of args is not within the expected range.
type ShellCompDirective ¶ added in v0.1.2
type ShellCompDirective int
ShellCompDirective is a bit map representing the different behaviors the shell can be instructed to have once completions have been provided.
const ( // ShellCompDirectiveError indicates an error occurred and completions should be ignored. ShellCompDirectiveError ShellCompDirective = 1 << iota // ShellCompDirectiveNoSpace indicates that the shell should not add a space // after the completion even if there is a single completion provided. ShellCompDirectiveNoSpace // ShellCompDirectiveNoFileComp indicates that the shell should not provide // file completion even when no completion is provided. ShellCompDirectiveNoFileComp // ShellCompDirectiveFilterFileExt indicates that the provided completions // should be used as file extension filters. // For flags, using Command.MarkFlagFilename() and Command.MarkPersistentFlagFilename() // is a shortcut to using this directive explicitly. The BashCompFilenameExt // annotation can also be used to obtain the same behavior for flags. ShellCompDirectiveFilterFileExt // ShellCompDirectiveFilterDirs indicates that only directory names should // be provided in file completion. To request directory names within another // directory, the returned completions should specify the directory within // which to search. The BashCompSubdirsInDir annotation can be used to // obtain the same behavior but only for flags. ShellCompDirectiveFilterDirs // ShellCompDirectiveDefault indicates to let the shell perform its default // behavior after completions have been provided. // This one must be last to avoid messing up the iota count. ShellCompDirectiveDefault ShellCompDirective = 0 )
func NoFileCompletions ¶ added in v0.1.2
func NoFileCompletions(cmd *Command, args []string, toComplete string) ([]string, ShellCompDirective)
NoFileCompletions can be used to disable file completion for commands that should not trigger file completions.